@@ -613,7 +613,7 @@ int ft_boolean_read_next(FT_INFO *ftb, char *record)
       info->lastpos=pos;
       if (!(my_thread_var->sen_flags & (SENNA_USE_2IND | SENNA_IF_READ_RECORD | 
 					SENNA_FILESORT))) {
-	SEN_LOG(sen_log_debug, "ft_boolean_read_next: 2ind return 0");
+	SEN_LOG(sen_log_dump, "ft_boolean_read_next: 2ind return 0");
 	return 0;
       }
       if (!(*info->read_record)(info,info->lastpos,record)) {
@@ -707,7 +707,7 @@ float ft_boolean_find_relevance(FT_INFO *ftb, byte *record, uint length)
     if (!ftb->sir) { return 0.0; }
     if (docid == HA_OFFSET_ERROR)
       return -2.0;
-    SEN_LOG(sen_log_debug, "ft_boolean_find_relevance => sen_records_find: records=%p, key=%p",
+    SEN_LOG(sen_log_dump, "ft_boolean_find_relevance => sen_records_find: records=%p, key=%p",
 	    ftb->sir, &docid);
     return 1.0 * sen_records_find(ftb->sir, &docid);
   }
@@ -822,7 +822,7 @@ float ft_boolean_get_relevance(FT_INFO *ftb)
   if ((ftb->keynr != NO_SUCH_KEY) && ftb->info->s->keyinfo[ftb->keynr].senna)
   {
     if (!ftb->sir) { return 0.0; }
-    SEN_LOG(sen_log_debug, "ft_boolean_get_relevance => sen_records_curr_score: r=%p", ftb->sir);
+    SEN_LOG(sen_log_dump, "ft_boolean_get_relevance => sen_records_curr_score: r=%p", ftb->sir);
     return 1.0 * sen_records_curr_score(ftb->sir);
   }
 #endif /* ENABLE_SENNA */
