@@ -28,7 +28,7 @@
 #ifdef HAVE_OPENSSL
 #include <openssl/des.h>
 #endif /* HAVE_OPENSSL */
-#include "md5.h"
+#include "my_md5.h"
 #include "sha1.h"
 #include "my_aes.h"
 C_MODE_START
@@ -1148,8 +1148,9 @@ String *Item_func_substr::val_str(String *str)
 		   (arg_count == 3 && args[2]->null_value))))
     return 0; /* purecov: inspected */
 
-  /* Negative length, will return empty string. */
-  if ((arg_count == 3) && (length <= 0) && !args[2]->unsigned_flag)
+  /* Negative or zero length, will return empty string. */
+  if ((arg_count == 3) && (length <= 0) && 
+      (length == 0 || !args[2]->unsigned_flag))
     return &my_empty_string;
 
   /* Assumes that the maximum length of a String is < INT_MAX32. */
@@ -2675,7 +2676,8 @@ void Item_func_set_collation::fix_length_and_dec()
              colname, args[0]->collation.collation->csname);
     return;
   }
-  collation.set(set_collation, DERIVATION_EXPLICIT);
+  collation.set(set_collation, DERIVATION_EXPLICIT,
+                args[0]->collation.repertoire);
   max_length= args[0]->max_length;
 }
 
@@ -3423,10 +3425,7 @@ String *Item_func_senna_kwic::val_str(String *str)
   uint result_len;
   int i;
 
-  if (str == NULL) {
-    SEN_LOG(sen_log_warning, "Item_func_senna_snipet::val_str(null) is called");
-    goto err_null;
-  }
+  null_value=0;
 
   if (arg_count < 9 || arg_count % 3 != 0) {
     SEN_LOG(sen_log_warning, "Incorrect number of arguments for kwic: %d", arg_count);
@@ -3434,7 +3433,7 @@ String *Item_func_senna_kwic::val_str(String *str)
   }
 
   for (i = 0; i < arg_count; i++) {
-    if (args[i]->null_value) {
+    if (!(args[i]->val_str(str))) {
       SEN_LOG(sen_log_warning, "kwic argument #%d is null", i+1);
       goto err_null;
     }
@@ -3457,6 +3456,7 @@ String *Item_func_senna_kwic::val_str(String *str)
     return &my_empty_string;
   }
 
+  if (target == NULL) return &my_empty_string;
   encoding = senna_enc_senna(target->charset()->csname);
   if (html_encoding == 1) {
     mapping = (sen_snip_mapping *) -1;
@@ -3509,6 +3509,7 @@ String *Item_func_senna_kwic::val_str(String *str)
     return &my_empty_string;
   }
 
+
   if (!(result = sql_alloc(max_tagged_len))) {
     SEN_LOG(sen_log_error, "sql_alloc failed", rc);
     SEN_LOG(sen_log_debug, "Item_func_senna_kwic::val_str => sen_snip_close: " \
@@ -3519,32 +3520,36 @@ String *Item_func_senna_kwic::val_str(String *str)
     return &my_empty_string;
   }
 
-  SEN_LOG(sen_log_debug, "Item_func_senna_kwic::val_str => sen_snip_get_result: " \
-	  "%p, 0, %p, %p", snip, result, &result_len);
-  if ((rc = sen_snip_get_result(snip, 0, result, &result_len))) {
-    SEN_LOG(sen_log_error, "sen_snip_get_result failed: sen_rc= %d", rc);
-    SEN_LOG(sen_log_debug, "Item_func_senna_kwic::val_str => sen_snip_close: " \
-	    "snip = %p", snip);
-    if ((rc = sen_snip_close(snip))) {
-      SEN_LOG(sen_log_error, "sen_snip_close failed: sen_rc = %d", rc);
-    }
-    return &my_empty_string;
-  }
+  str->copy("", 0, target->charset());
 
-  if (result_len <= 0) {
-    SEN_LOG(sen_log_error, "result_len is not positive value: %d", result_len);
-    SEN_LOG(sen_log_debug, "Item_func_senna_kwic::val_str => sen_snip_close: " \
-            "snip = %p", snip);
-    if ((rc = sen_snip_close(snip))) {
-      SEN_LOG(sen_log_error, "sen_snip_close failed: sen_rc = %d", rc);
+  for (i = 0; i < nresults; i++) {
+    SEN_LOG(sen_log_debug, "Item_func_senna_kwic::val_str => sen_snip_get_result: " \
+	    "%p, 0, %p, %p", snip, result, &result_len);
+    if ((rc = sen_snip_get_result(snip, i, result, &result_len))) {
+      SEN_LOG(sen_log_error, "sen_snip_get_result failed: sen_rc= %d", rc);
+      SEN_LOG(sen_log_debug, "Item_func_senna_kwic::val_str => sen_snip_close: " \
+	      "snip = %p", snip);
+      if ((rc = sen_snip_close(snip))) {
+	SEN_LOG(sen_log_error, "sen_snip_close failed: sen_rc = %d", rc);
+      }
+      return &my_empty_string;
     }
-    return &my_empty_string;
+    
+    if (result_len <= 0) {
+      SEN_LOG(sen_log_error, "result_len is not positive value: %d", result_len);
+      SEN_LOG(sen_log_debug, "Item_func_senna_kwic::val_str => sen_snip_close: " \
+	      "snip = %p", snip);
+      if ((rc = sen_snip_close(snip))) {
+	SEN_LOG(sen_log_error, "sen_snip_close failed: sen_rc = %d", rc);
+      }
+      return &my_empty_string;
+    }
+    
+    str->append(start->ptr(), start->length(), target->charset());
+    str->append(result, result_len, target->charset());
+    str->append(end->ptr(), end->length(), target->charset());
   }
 
-  str->copy(start->ptr(), start->length(), target->charset());
-  str->append(result, result_len, target->charset());
-  str->append(end->ptr(), end->length(), target->charset());
-
   SEN_LOG(sen_log_debug, "Item_func_senna_kwic::val_str => sen_snip_close: " \
 	  "snip = %p", snip);
   if ((rc = sen_snip_close(snip))) {
