@@ -1,7 +1,9 @@
-/* A Bison parser, made by GNU Bison 1.875c.  */
+/* A Bison parser, made by GNU Bison 2.3.  */
 
-/* Skeleton parser for Yacc-like parsing with Bison,
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.
+/* Skeleton interface for Bison's Yacc-like parsers in C
+
+   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -15,13 +17,21 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.  */
 
-/* As a special exception, when this file is copied by Bison into a
-   Bison output file, you may use that output file without restriction.
-   This special exception was added by the Free Software Foundation
-   in version 1.24 of Bison.  */
+/* As a special exception, you may create a larger work that contains
+   part or all of the Bison parser skeleton and distribute that work
+   under terms of your choice, so long as that work isn't itself a
+   parser generator using the skeleton or a modified version thereof
+   as a parser skeleton.  Alternatively, if you modify or redistribute
+   the parser skeleton itself, you may (at your option) remove this
+   special exception, which will cause the skeleton and the resulting
+   Bison output files to be licensed under the GNU General Public
+   License without this special exception.
+
+   This special exception was added by the Free Software Foundation in
+   version 2.2 of Bison.  */
 
 /* Tokens.  */
 #ifndef YYTOKENTYPE
@@ -458,145 +468,151 @@
      SECURITY_SYM = 684,
      SELECT_SYM = 685,
      SENNA_DELIMITED_SYM = 686,
-     SENNA_NGRAM_SYM = 687,
-     SENNA_NORMALIZE_SYM = 688,
-     SENNA_SECTIONALIZE_SYM = 689,
-     SENNA_SYM = 690,
-     SENSITIVE_SYM = 691,
-     SEPARATOR_SYM = 692,
-     SERIALIZABLE_SYM = 693,
-     SERIAL_SYM = 694,
-     SESSION_SYM = 695,
-     SET = 696,
-     SET_VAR = 697,
-     SHARE_SYM = 698,
-     SHIFT_LEFT = 699,
-     SHIFT_RIGHT = 700,
-     SHOW = 701,
-     SHUTDOWN = 702,
-     SIGNED_SYM = 703,
-     SIMPLE_SYM = 704,
-     SLAVE = 705,
-     SMALLINT = 706,
-     SNAPSHOT_SYM = 707,
-     SOUNDS_SYM = 708,
-     SOURCE_SYM = 709,
-     SPATIAL_SYM = 710,
-     SPECIFIC_SYM = 711,
-     SQLEXCEPTION_SYM = 712,
-     SQLSTATE_SYM = 713,
-     SQLWARNING_SYM = 714,
-     SQL_BIG_RESULT = 715,
-     SQL_BUFFER_RESULT = 716,
-     SQL_CACHE_SYM = 717,
-     SQL_CALC_FOUND_ROWS = 718,
-     SQL_NO_CACHE_SYM = 719,
-     SQL_SMALL_RESULT = 720,
-     SQL_SYM = 721,
-     SQL_THREAD = 722,
-     SSL_SYM = 723,
-     STARTING = 724,
-     START_SYM = 725,
-     STATUS_SYM = 726,
-     STD_SYM = 727,
-     STDDEV_SAMP_SYM = 728,
-     STOP_SYM = 729,
-     STORAGE_SYM = 730,
-     STRAIGHT_JOIN = 731,
-     STRING_SYM = 732,
-     SUBDATE_SYM = 733,
-     SUBJECT_SYM = 734,
-     SUBSTRING = 735,
-     SUBSTRING_INDEX = 736,
-     SUM_SYM = 737,
-     SUPER_SYM = 738,
-     SUSPEND_SYM = 739,
-     SWAPS_SYM = 740,
-     SWITCHES_SYM = 741,
-     SYSDATE = 742,
-     TABLES = 743,
-     TABLESPACE = 744,
-     TABLE_SYM = 745,
-     TEMPORARY = 746,
-     TEMPTABLE_SYM = 747,
-     TERMINATED = 748,
-     TEXT_STRING = 749,
-     TEXT_SYM = 750,
-     TIMESTAMP = 751,
-     TIMESTAMP_ADD = 752,
-     TIMESTAMP_DIFF = 753,
-     TIME_SYM = 754,
-     TINYBLOB = 755,
-     TINYINT = 756,
-     TINYTEXT = 757,
-     TO_SYM = 758,
-     TRAILING = 759,
-     TRANSACTION_SYM = 760,
-     TRIGGER_SYM = 761,
-     TRIGGERS_SYM = 762,
-     TRIM = 763,
-     TRUE_SYM = 764,
-     TRUNCATE_SYM = 765,
-     TYPES_SYM = 766,
-     TYPE_SYM = 767,
-     UDF_RETURNS_SYM = 768,
-     UDF_SONAME_SYM = 769,
-     ULONGLONG_NUM = 770,
-     UNCOMMITTED_SYM = 771,
-     UNDEFINED_SYM = 772,
-     UNDERSCORE_CHARSET = 773,
-     UNDO_SYM = 774,
-     UNICODE_SYM = 775,
-     UNION_SYM = 776,
-     UNIQUE_SYM = 777,
-     UNIQUE_USERS = 778,
-     UNIX_TIMESTAMP = 779,
-     UNKNOWN_SYM = 780,
-     UNLOCK_SYM = 781,
-     UNSIGNED = 782,
-     UNTIL_SYM = 783,
-     UPDATE_SYM = 784,
-     UPGRADE_SYM = 785,
-     USAGE = 786,
-     USER = 787,
-     USE_FRM = 788,
-     USE_SYM = 789,
-     USING = 790,
-     UTC_DATE_SYM = 791,
-     UTC_TIMESTAMP_SYM = 792,
-     UTC_TIME_SYM = 793,
-     VAR_SAMP_SYM = 794,
-     VALUES = 795,
-     VALUE_SYM = 796,
-     VARBINARY = 797,
-     VARCHAR = 798,
-     VARIABLES = 799,
-     VARIANCE_SYM = 800,
-     VARYING = 801,
-     VIEW_SYM = 802,
-     WARNINGS = 803,
-     WEEK_SYM = 804,
-     WHEN_SYM = 805,
-     WHERE = 806,
-     WHILE_SYM = 807,
-     WITH = 808,
-     WORK_SYM = 809,
-     WRITE_SYM = 810,
-     X509_SYM = 811,
-     XA_SYM = 812,
-     XOR = 813,
-     YEARWEEK = 814,
-     YEAR_MONTH_SYM = 815,
-     YEAR_SYM = 816,
-     ZEROFILL = 817,
-     TABLE_REF_PRIORITY = 818,
-     ELSE = 819,
-     THEN_SYM = 820,
-     CASE_SYM = 821,
-     BETWEEN_SYM = 822,
-     NEG = 823
+     SENNA_KWIC_SYM = 687,
+     SENNA_MECAB_SYM = 688,
+     SENNA_NGRAM_SYM = 689,
+     SENNA_NORMALIZE_SYM = 690,
+     SENNA_SECTIONALIZE_SYM = 691,
+     SENNA_SPLIT_ALPHA_SYM = 692,
+     SENNA_SPLIT_DIGIT_SYM = 693,
+     SENNA_SPLIT_SYMBOL_SYM = 694,
+     SENNA_SYM = 695,
+     SENSITIVE_SYM = 696,
+     SEPARATOR_SYM = 697,
+     SERIALIZABLE_SYM = 698,
+     SERIAL_SYM = 699,
+     SESSION_SYM = 700,
+     SET = 701,
+     SET_VAR = 702,
+     SHARE_SYM = 703,
+     SHIFT_LEFT = 704,
+     SHIFT_RIGHT = 705,
+     SHOW = 706,
+     SHUTDOWN = 707,
+     SIGNED_SYM = 708,
+     SIMPLE_SYM = 709,
+     SLAVE = 710,
+     SMALLINT = 711,
+     SNAPSHOT_SYM = 712,
+     SOUNDS_SYM = 713,
+     SOURCE_SYM = 714,
+     SPATIAL_SYM = 715,
+     SPECIFIC_SYM = 716,
+     SQLEXCEPTION_SYM = 717,
+     SQLSTATE_SYM = 718,
+     SQLWARNING_SYM = 719,
+     SQL_BIG_RESULT = 720,
+     SQL_BUFFER_RESULT = 721,
+     SQL_CACHE_SYM = 722,
+     SQL_CALC_FOUND_ROWS = 723,
+     SQL_NO_CACHE_SYM = 724,
+     SQL_SMALL_RESULT = 725,
+     SQL_SYM = 726,
+     SQL_THREAD = 727,
+     SSL_SYM = 728,
+     STARTING = 729,
+     START_SYM = 730,
+     STATUS_SYM = 731,
+     STD_SYM = 732,
+     STDDEV_SAMP_SYM = 733,
+     STOP_SYM = 734,
+     STORAGE_SYM = 735,
+     STRAIGHT_JOIN = 736,
+     STRING_SYM = 737,
+     SUBDATE_SYM = 738,
+     SUBJECT_SYM = 739,
+     SUBSTRING = 740,
+     SUBSTRING_INDEX = 741,
+     SUM_SYM = 742,
+     SUPER_SYM = 743,
+     SUSPEND_SYM = 744,
+     SWAPS_SYM = 745,
+     SWITCHES_SYM = 746,
+     SYSDATE = 747,
+     TABLES = 748,
+     TABLESPACE = 749,
+     TABLE_SYM = 750,
+     TEMPORARY = 751,
+     TEMPTABLE_SYM = 752,
+     TERMINATED = 753,
+     TEXT_STRING = 754,
+     TEXT_SYM = 755,
+     TIMESTAMP = 756,
+     TIMESTAMP_ADD = 757,
+     TIMESTAMP_DIFF = 758,
+     TIME_SYM = 759,
+     TINYBLOB = 760,
+     TINYINT = 761,
+     TINYTEXT = 762,
+     TO_SYM = 763,
+     TRAILING = 764,
+     TRANSACTION_SYM = 765,
+     TRIGGER_SYM = 766,
+     TRIGGERS_SYM = 767,
+     TRIM = 768,
+     TRUE_SYM = 769,
+     TRUNCATE_SYM = 770,
+     TYPES_SYM = 771,
+     TYPE_SYM = 772,
+     UDF_RETURNS_SYM = 773,
+     UDF_SONAME_SYM = 774,
+     ULONGLONG_NUM = 775,
+     UNCOMMITTED_SYM = 776,
+     UNDEFINED_SYM = 777,
+     UNDERSCORE_CHARSET = 778,
+     UNDO_SYM = 779,
+     UNICODE_SYM = 780,
+     UNION_SYM = 781,
+     UNIQUE_SYM = 782,
+     UNIQUE_USERS = 783,
+     UNIX_TIMESTAMP = 784,
+     UNKNOWN_SYM = 785,
+     UNLOCK_SYM = 786,
+     UNSIGNED = 787,
+     UNTIL_SYM = 788,
+     UPDATE_SYM = 789,
+     UPGRADE_SYM = 790,
+     USAGE = 791,
+     USER = 792,
+     USE_FRM = 793,
+     USE_SYM = 794,
+     USING = 795,
+     UTC_DATE_SYM = 796,
+     UTC_TIMESTAMP_SYM = 797,
+     UTC_TIME_SYM = 798,
+     VAR_SAMP_SYM = 799,
+     VALUES = 800,
+     VALUE_SYM = 801,
+     VARBINARY = 802,
+     VARCHAR = 803,
+     VARIABLES = 804,
+     VARIANCE_SYM = 805,
+     VARYING = 806,
+     VIEW_SYM = 807,
+     WARNINGS = 808,
+     WEEK_SYM = 809,
+     WHEN_SYM = 810,
+     WHERE = 811,
+     WHILE_SYM = 812,
+     WITH = 813,
+     WORK_SYM = 814,
+     WRITE_SYM = 815,
+     X509_SYM = 816,
+     XA_SYM = 817,
+     XOR = 818,
+     YEARWEEK = 819,
+     YEAR_MONTH_SYM = 820,
+     YEAR_SYM = 821,
+     ZEROFILL = 822,
+     TABLE_REF_PRIORITY = 823,
+     ELSE = 824,
+     THEN_SYM = 825,
+     CASE_SYM = 826,
+     BETWEEN_SYM = 827,
+     NEG = 828
    };
 #endif
+/* Tokens.  */
 #define END_OF_INPUT 258
 #define ABORT_SYM 259
 #define ACTION 260
@@ -1026,150 +1042,156 @@
 #define SECURITY_SYM 684
 #define SELECT_SYM 685
 #define SENNA_DELIMITED_SYM 686
-#define SENNA_NGRAM_SYM 687
-#define SENNA_NORMALIZE_SYM 688
-#define SENNA_SECTIONALIZE_SYM 689
-#define SENNA_SYM 690
-#define SENSITIVE_SYM 691
-#define SEPARATOR_SYM 692
-#define SERIALIZABLE_SYM 693
-#define SERIAL_SYM 694
-#define SESSION_SYM 695
-#define SET 696
-#define SET_VAR 697
-#define SHARE_SYM 698
-#define SHIFT_LEFT 699
-#define SHIFT_RIGHT 700
-#define SHOW 701
-#define SHUTDOWN 702
-#define SIGNED_SYM 703
-#define SIMPLE_SYM 704
-#define SLAVE 705
-#define SMALLINT 706
-#define SNAPSHOT_SYM 707
-#define SOUNDS_SYM 708
-#define SOURCE_SYM 709
-#define SPATIAL_SYM 710
-#define SPECIFIC_SYM 711
-#define SQLEXCEPTION_SYM 712
-#define SQLSTATE_SYM 713
-#define SQLWARNING_SYM 714
-#define SQL_BIG_RESULT 715
-#define SQL_BUFFER_RESULT 716
-#define SQL_CACHE_SYM 717
-#define SQL_CALC_FOUND_ROWS 718
-#define SQL_NO_CACHE_SYM 719
-#define SQL_SMALL_RESULT 720
-#define SQL_SYM 721
-#define SQL_THREAD 722
-#define SSL_SYM 723
-#define STARTING 724
-#define START_SYM 725
-#define STATUS_SYM 726
-#define STD_SYM 727
-#define STDDEV_SAMP_SYM 728
-#define STOP_SYM 729
-#define STORAGE_SYM 730
-#define STRAIGHT_JOIN 731
-#define STRING_SYM 732
-#define SUBDATE_SYM 733
-#define SUBJECT_SYM 734
-#define SUBSTRING 735
-#define SUBSTRING_INDEX 736
-#define SUM_SYM 737
-#define SUPER_SYM 738
-#define SUSPEND_SYM 739
-#define SWAPS_SYM 740
-#define SWITCHES_SYM 741
-#define SYSDATE 742
-#define TABLES 743
-#define TABLESPACE 744
-#define TABLE_SYM 745
-#define TEMPORARY 746
-#define TEMPTABLE_SYM 747
-#define TERMINATED 748
-#define TEXT_STRING 749
-#define TEXT_SYM 750
-#define TIMESTAMP 751
-#define TIMESTAMP_ADD 752
-#define TIMESTAMP_DIFF 753
-#define TIME_SYM 754
-#define TINYBLOB 755
-#define TINYINT 756
-#define TINYTEXT 757
-#define TO_SYM 758
-#define TRAILING 759
-#define TRANSACTION_SYM 760
-#define TRIGGER_SYM 761
-#define TRIGGERS_SYM 762
-#define TRIM 763
-#define TRUE_SYM 764
-#define TRUNCATE_SYM 765
-#define TYPES_SYM 766
-#define TYPE_SYM 767
-#define UDF_RETURNS_SYM 768
-#define UDF_SONAME_SYM 769
-#define ULONGLONG_NUM 770
-#define UNCOMMITTED_SYM 771
-#define UNDEFINED_SYM 772
-#define UNDERSCORE_CHARSET 773
-#define UNDO_SYM 774
-#define UNICODE_SYM 775
-#define UNION_SYM 776
-#define UNIQUE_SYM 777
-#define UNIQUE_USERS 778
-#define UNIX_TIMESTAMP 779
-#define UNKNOWN_SYM 780
-#define UNLOCK_SYM 781
-#define UNSIGNED 782
-#define UNTIL_SYM 783
-#define UPDATE_SYM 784
-#define UPGRADE_SYM 785
-#define USAGE 786
-#define USER 787
-#define USE_FRM 788
-#define USE_SYM 789
-#define USING 790
-#define UTC_DATE_SYM 791
-#define UTC_TIMESTAMP_SYM 792
-#define UTC_TIME_SYM 793
-#define VAR_SAMP_SYM 794
-#define VALUES 795
-#define VALUE_SYM 796
-#define VARBINARY 797
-#define VARCHAR 798
-#define VARIABLES 799
-#define VARIANCE_SYM 800
-#define VARYING 801
-#define VIEW_SYM 802
-#define WARNINGS 803
-#define WEEK_SYM 804
-#define WHEN_SYM 805
-#define WHERE 806
-#define WHILE_SYM 807
-#define WITH 808
-#define WORK_SYM 809
-#define WRITE_SYM 810
-#define X509_SYM 811
-#define XA_SYM 812
-#define XOR 813
-#define YEARWEEK 814
-#define YEAR_MONTH_SYM 815
-#define YEAR_SYM 816
-#define ZEROFILL 817
-#define TABLE_REF_PRIORITY 818
-#define ELSE 819
-#define THEN_SYM 820
-#define CASE_SYM 821
-#define BETWEEN_SYM 822
-#define NEG 823
+#define SENNA_KWIC_SYM 687
+#define SENNA_MECAB_SYM 688
+#define SENNA_NGRAM_SYM 689
+#define SENNA_NORMALIZE_SYM 690
+#define SENNA_SECTIONALIZE_SYM 691
+#define SENNA_SPLIT_ALPHA_SYM 692
+#define SENNA_SPLIT_DIGIT_SYM 693
+#define SENNA_SPLIT_SYMBOL_SYM 694
+#define SENNA_SYM 695
+#define SENSITIVE_SYM 696
+#define SEPARATOR_SYM 697
+#define SERIALIZABLE_SYM 698
+#define SERIAL_SYM 699
+#define SESSION_SYM 700
+#define SET 701
+#define SET_VAR 702
+#define SHARE_SYM 703
+#define SHIFT_LEFT 704
+#define SHIFT_RIGHT 705
+#define SHOW 706
+#define SHUTDOWN 707
+#define SIGNED_SYM 708
+#define SIMPLE_SYM 709
+#define SLAVE 710
+#define SMALLINT 711
+#define SNAPSHOT_SYM 712
+#define SOUNDS_SYM 713
+#define SOURCE_SYM 714
+#define SPATIAL_SYM 715
+#define SPECIFIC_SYM 716
+#define SQLEXCEPTION_SYM 717
+#define SQLSTATE_SYM 718
+#define SQLWARNING_SYM 719
+#define SQL_BIG_RESULT 720
+#define SQL_BUFFER_RESULT 721
+#define SQL_CACHE_SYM 722
+#define SQL_CALC_FOUND_ROWS 723
+#define SQL_NO_CACHE_SYM 724
+#define SQL_SMALL_RESULT 725
+#define SQL_SYM 726
+#define SQL_THREAD 727
+#define SSL_SYM 728
+#define STARTING 729
+#define START_SYM 730
+#define STATUS_SYM 731
+#define STD_SYM 732
+#define STDDEV_SAMP_SYM 733
+#define STOP_SYM 734
+#define STORAGE_SYM 735
+#define STRAIGHT_JOIN 736
+#define STRING_SYM 737
+#define SUBDATE_SYM 738
+#define SUBJECT_SYM 739
+#define SUBSTRING 740
+#define SUBSTRING_INDEX 741
+#define SUM_SYM 742
+#define SUPER_SYM 743
+#define SUSPEND_SYM 744
+#define SWAPS_SYM 745
+#define SWITCHES_SYM 746
+#define SYSDATE 747
+#define TABLES 748
+#define TABLESPACE 749
+#define TABLE_SYM 750
+#define TEMPORARY 751
+#define TEMPTABLE_SYM 752
+#define TERMINATED 753
+#define TEXT_STRING 754
+#define TEXT_SYM 755
+#define TIMESTAMP 756
+#define TIMESTAMP_ADD 757
+#define TIMESTAMP_DIFF 758
+#define TIME_SYM 759
+#define TINYBLOB 760
+#define TINYINT 761
+#define TINYTEXT 762
+#define TO_SYM 763
+#define TRAILING 764
+#define TRANSACTION_SYM 765
+#define TRIGGER_SYM 766
+#define TRIGGERS_SYM 767
+#define TRIM 768
+#define TRUE_SYM 769
+#define TRUNCATE_SYM 770
+#define TYPES_SYM 771
+#define TYPE_SYM 772
+#define UDF_RETURNS_SYM 773
+#define UDF_SONAME_SYM 774
+#define ULONGLONG_NUM 775
+#define UNCOMMITTED_SYM 776
+#define UNDEFINED_SYM 777
+#define UNDERSCORE_CHARSET 778
+#define UNDO_SYM 779
+#define UNICODE_SYM 780
+#define UNION_SYM 781
+#define UNIQUE_SYM 782
+#define UNIQUE_USERS 783
+#define UNIX_TIMESTAMP 784
+#define UNKNOWN_SYM 785
+#define UNLOCK_SYM 786
+#define UNSIGNED 787
+#define UNTIL_SYM 788
+#define UPDATE_SYM 789
+#define UPGRADE_SYM 790
+#define USAGE 791
+#define USER 792
+#define USE_FRM 793
+#define USE_SYM 794
+#define USING 795
+#define UTC_DATE_SYM 796
+#define UTC_TIMESTAMP_SYM 797
+#define UTC_TIME_SYM 798
+#define VAR_SAMP_SYM 799
+#define VALUES 800
+#define VALUE_SYM 801
+#define VARBINARY 802
+#define VARCHAR 803
+#define VARIABLES 804
+#define VARIANCE_SYM 805
+#define VARYING 806
+#define VIEW_SYM 807
+#define WARNINGS 808
+#define WEEK_SYM 809
+#define WHEN_SYM 810
+#define WHERE 811
+#define WHILE_SYM 812
+#define WITH 813
+#define WORK_SYM 814
+#define WRITE_SYM 815
+#define X509_SYM 816
+#define XA_SYM 817
+#define XOR 818
+#define YEARWEEK 819
+#define YEAR_MONTH_SYM 820
+#define YEAR_SYM 821
+#define ZEROFILL 822
+#define TABLE_REF_PRIORITY 823
+#define ELSE 824
+#define THEN_SYM 825
+#define CASE_SYM 826
+#define BETWEEN_SYM 827
+#define NEG 828
 
 
 
 
-#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
+#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
+typedef union YYSTYPE
 #line 415 "sql_yacc.yy"
-typedef union YYSTYPE {
+{
   int  num;
   ulong ulong_num;
   ulonglong ulonglong_number;
@@ -1207,9 +1229,10 @@ typedef union YYSTYPE {
   struct { int vars, conds, hndlrs, curs; } spblock;
   sp_name *spname;
   struct st_lex *lex;
-} YYSTYPE;
-/* Line 1275 of yacc.c.  */
-#line 1213 "sql_yacc.h"
+}
+/* Line 1529 of yacc.c.  */
+#line 1235 "sql_yacc.h"
+	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
@@ -1217,5 +1240,3 @@ typedef union YYSTYPE {
 
 
 
-
-
