@@ -19,7 +19,7 @@
 #include "mysql_priv.h"
 #include <errno.h>
 #include <m_ctype.h>
-#include "md5.h"
+#include "my_md5.h"
 
 	/* Functions defined in this file */
 
@@ -109,6 +109,18 @@ int openfrm(THD *thd, const char *name, const char *alias, uint db_stat,
   if (my_read(file,(byte*) head,64,MYF(MY_NABP)))
     goto err;
 
+#ifdef ENABLE_SENNA
+  if (prgflag & SENNA_CHECK_VIEW)
+  {
+    if (memcmp(head, STRING_WITH_LEN("TYPE=VIEW")) == 0)
+    {
+      error_reported = TRUE;
+      error = 0;
+      goto err;
+    }
+  }
+#endif
+
   if (memcmp(head, STRING_WITH_LEN("TYPE=")) == 0)
   {
     // new .frm
@@ -780,7 +792,11 @@ int openfrm(THD *thd, const char *name, const char *alias, uint db_stat,
 	      the primary key, then we can use any key to find this column
 	    */
 	    if (ha_option & HA_PRIMARY_KEY_IN_READ_INDEX)
+            {
 	      field->part_of_key= share->keys_in_use;
+              if (field->part_of_sortkey.is_set(key))
+                field->part_of_sortkey= share->keys_in_use;
+            }
 	  }
 	  if (field->key_length() != key_part->length)
 	  {
@@ -1442,7 +1458,19 @@ File create_frm(THD *thd, my_string name, const char *db,
     fileinfo[3]= (uchar) ha_checktype(thd,create_info->db_type,0,0);
     fileinfo[4]=1;
     int2store(fileinfo+6,IO_SIZE);		/* Next block starts here */
-    key_length=keys*(7+NAME_LEN+MAX_REF_PARTS*9)+16;
+    /*
+      Keep in sync with pack_keys() in unireg.cc
+      For each key:
+      8 bytes for the key header
+      9 bytes for each key-part (MAX_REF_PARTS)
+      NAME_LEN bytes for the name
+      1 byte for the NAMES_SEP_CHAR (before the name)
+      For all keys:
+      6 bytes for the header
+      1 byte for the NAMES_SEP_CHAR (after the last name)
+      9 extra bytes (padding for safety? alignment?)
+    */
+    key_length= keys * (8 + MAX_REF_PARTS * 9 + NAME_LEN + 1) + 16;
     length= next_io_size((ulong) (IO_SIZE+key_length+reclength+
                                   create_info->extra_size));
     int4store(fileinfo+10,length);
@@ -1768,11 +1796,11 @@ void st_table::reset_item_list(List<Item> *item_list) const
   calculate md5 of query
 
   SYNOPSIS
-    st_table_list::calc_md5()
+    TABLE_LIST::calc_md5()
     buffer	buffer for md5 writing
 */
 
-void  st_table_list::calc_md5(char *buffer)
+void  TABLE_LIST::calc_md5(char *buffer)
 {
   my_MD5_CTX context;
   uchar digest[16];
@@ -1797,10 +1825,10 @@ void  st_table_list::calc_md5(char *buffer)
     it (it is a kind of optimisation)
 
   SYNOPSIS
-    st_table_list::set_underlying_merge()
+    TABLE_LIST::set_underlying_merge()
 */
 
-void st_table_list::set_underlying_merge()
+void TABLE_LIST::set_underlying_merge()
 {
   TABLE_LIST *tbl;
 
@@ -1835,7 +1863,7 @@ void st_table_list::set_underlying_merge()
   setup fields of placeholder of merged VIEW
 
   SYNOPSIS
-    st_table_list::setup_underlying()
+    TABLE_LIST::setup_underlying()
     thd		    - thread handler
 
   DESCRIPTION
@@ -1848,9 +1876,9 @@ void st_table_list::set_underlying_merge()
     TRUE  - error
 */
 
-bool st_table_list::setup_underlying(THD *thd)
+bool TABLE_LIST::setup_underlying(THD *thd)
 {
-  DBUG_ENTER("st_table_list::setup_underlying");
+  DBUG_ENTER("TABLE_LIST::setup_underlying");
 
   if (!field_translation && merge_underlying_list)
   {
@@ -1913,7 +1941,7 @@ bool st_table_list::setup_underlying(THD *thd)
   Prepare where expression of view
 
   SYNOPSIS
-    st_table_list::prep_where()
+    TABLE_LIST::prep_where()
     thd             - thread handler
     conds           - condition of this JOIN
     no_where_clause - do not build WHERE or ON outer qwery do not need it
@@ -1927,10 +1955,10 @@ bool st_table_list::setup_underlying(THD *thd)
     TRUE  - error
 */
 
-bool st_table_list::prep_where(THD *thd, Item **conds,
+bool TABLE_LIST::prep_where(THD *thd, Item **conds,
                                bool no_where_clause)
 {
-  DBUG_ENTER("st_table_list::prep_where");
+  DBUG_ENTER("TABLE_LIST::prep_where");
 
   for (TABLE_LIST *tbl= merge_underlying_list; tbl; tbl= tbl->next_local)
   {
@@ -2030,7 +2058,7 @@ merge_on_conds(THD *thd, TABLE_LIST *table, bool is_cascaded)
   Prepare check option expression of table
 
   SYNOPSIS
-    st_table_list::prep_check_option()
+    TABLE_LIST::prep_check_option()
     thd             - thread handler
     check_opt_type  - WITH CHECK OPTION type (VIEW_CHECK_NONE,
                       VIEW_CHECK_LOCAL, VIEW_CHECK_CASCADED)
@@ -2045,16 +2073,16 @@ merge_on_conds(THD *thd, TABLE_LIST *table, bool is_cascaded)
     This method builds check option condition to use it later on
     every call (usual execution or every SP/PS call).
     This method have to be called after WHERE preparation
-    (st_table_list::prep_where)
+    (TABLE_LIST::prep_where)
 
   RETURN
     FALSE - OK
     TRUE  - error
 */
 
-bool st_table_list::prep_check_option(THD *thd, uint8 check_opt_type)
+bool TABLE_LIST::prep_check_option(THD *thd, uint8 check_opt_type)
 {
-  DBUG_ENTER("st_table_list::prep_check_option");
+  DBUG_ENTER("TABLE_LIST::prep_check_option");
   bool is_cascaded= check_opt_type == VIEW_CHECK_CASCADED;
 
   for (TABLE_LIST *tbl= merge_underlying_list; tbl; tbl= tbl->next_local)
@@ -2113,12 +2141,12 @@ bool st_table_list::prep_check_option(THD *thd, uint8 check_opt_type)
   Hide errors which show view underlying table information
 
   SYNOPSIS
-    st_table_list::hide_view_error()
+    TABLE_LIST::hide_view_error()
     thd     thread handler
 
 */
 
-void st_table_list::hide_view_error(THD *thd)
+void TABLE_LIST::hide_view_error(THD *thd)
 {
   /* Hide "Unknown column" or "Unknown function" error */
   if (thd->net.last_errno == ER_BAD_FIELD_ERROR ||
@@ -2149,7 +2177,7 @@ void st_table_list::hide_view_error(THD *thd)
   table_to_find (TABLE)
 
   SYNOPSIS
-    st_table_list::find_underlying_table()
+    TABLE_LIST::find_underlying_table()
     table_to_find table to find
 
   RETURN
@@ -2157,7 +2185,7 @@ void st_table_list::hide_view_error(THD *thd)
     found table reference
 */
 
-st_table_list *st_table_list::find_underlying_table(TABLE *table_to_find)
+TABLE_LIST *TABLE_LIST::find_underlying_table(TABLE *table_to_find)
 {
   /* is this real table and table which we are looking for? */
   if (table == table_to_find && merge_underlying_list == 0)
@@ -2176,10 +2204,10 @@ st_table_list *st_table_list::find_underlying_table(TABLE *table_to_find)
   cleunup items belonged to view fields translation table
 
   SYNOPSIS
-    st_table_list::cleanup_items()
+    TABLE_LIST::cleanup_items()
 */
 
-void st_table_list::cleanup_items()
+void TABLE_LIST::cleanup_items()
 {
   if (!field_translation)
     return;
@@ -2195,7 +2223,7 @@ void st_table_list::cleanup_items()
   check CHECK OPTION condition
 
   SYNOPSIS
-    st_table_list::view_check_option()
+    TABLE_LIST::view_check_option()
     ignore_failure ignore check option fail
 
   RETURN
@@ -2204,7 +2232,7 @@ void st_table_list::cleanup_items()
     VIEW_CHECK_SKIP   FAILED, but continue
 */
 
-int st_table_list::view_check_option(THD *thd, bool ignore_failure)
+int TABLE_LIST::view_check_option(THD *thd, bool ignore_failure)
 {
   if (check_option && check_option->val_int() == 0)
   {
@@ -2229,7 +2257,7 @@ int st_table_list::view_check_option(THD *thd, bool ignore_failure)
   table belong to given mask
 
   SYNOPSIS
-    st_table_list::check_single_table()
+    TABLE_LIST::check_single_table()
     table_arg	reference on variable where to store found table
 		(should be 0 on call, to find table, or point to table for
 		unique test)
@@ -2241,9 +2269,9 @@ int st_table_list::view_check_option(THD *thd, bool ignore_failure)
     TRUE  found several tables
 */
 
-bool st_table_list::check_single_table(st_table_list **table_arg,
+bool TABLE_LIST::check_single_table(TABLE_LIST **table_arg,
                                        table_map map,
-                                       st_table_list *view_arg)
+                                       TABLE_LIST *view_arg)
 {
   for (TABLE_LIST *tbl= merge_underlying_list; tbl; tbl= tbl->next_local)
   {
@@ -2276,7 +2304,7 @@ bool st_table_list::check_single_table(st_table_list **table_arg,
     TRUE  - out of memory
 */
 
-bool st_table_list::set_insert_values(MEM_ROOT *mem_root)
+bool TABLE_LIST::set_insert_values(MEM_ROOT *mem_root)
 {
   if (table)
   {
@@ -2300,7 +2328,7 @@ bool st_table_list::set_insert_values(MEM_ROOT *mem_root)
   Test if this is a leaf with respect to name resolution.
 
   SYNOPSIS
-    st_table_list::is_leaf_for_name_resolution()
+    TABLE_LIST::is_leaf_for_name_resolution()
 
   DESCRIPTION
     A table reference is a leaf with respect to name resolution if
@@ -2312,7 +2340,7 @@ bool st_table_list::set_insert_values(MEM_ROOT *mem_root)
   RETURN
     TRUE if a leaf, FALSE otherwise.
 */
-bool st_table_list::is_leaf_for_name_resolution()
+bool TABLE_LIST::is_leaf_for_name_resolution()
 {
   return (view || is_natural_join || is_join_columns_complete ||
           !nested_join);
@@ -2324,7 +2352,7 @@ bool st_table_list::is_leaf_for_name_resolution()
   respect to name resolution.
 
   SYNOPSIS
-    st_table_list::first_leaf_for_name_resolution()
+    TABLE_LIST::first_leaf_for_name_resolution()
 
   DESCRIPTION
     Given that 'this' is a nested table reference, recursively walk
@@ -2342,7 +2370,7 @@ bool st_table_list::is_leaf_for_name_resolution()
     else return 'this'
 */
 
-TABLE_LIST *st_table_list::first_leaf_for_name_resolution()
+TABLE_LIST *TABLE_LIST::first_leaf_for_name_resolution()
 {
   TABLE_LIST *cur_table_ref;
   NESTED_JOIN *cur_nested_join;
@@ -2382,7 +2410,7 @@ TABLE_LIST *st_table_list::first_leaf_for_name_resolution()
   respect to name resolution.
 
   SYNOPSIS
-    st_table_list::last_leaf_for_name_resolution()
+    TABLE_LIST::last_leaf_for_name_resolution()
 
   DESCRIPTION
     Given that 'this' is a nested table reference, recursively walk
@@ -2400,7 +2428,7 @@ TABLE_LIST *st_table_list::first_leaf_for_name_resolution()
     - else - 'this'
 */
 
-TABLE_LIST *st_table_list::last_leaf_for_name_resolution()
+TABLE_LIST *TABLE_LIST::last_leaf_for_name_resolution()
 {
   TABLE_LIST *cur_table_ref= this;
   NESTED_JOIN *cur_nested_join;
@@ -2442,7 +2470,7 @@ TABLE_LIST *st_table_list::last_leaf_for_name_resolution()
     want_access          Acess which we require
 */
 
-void st_table_list::register_want_access(ulong want_access)
+void TABLE_LIST::register_want_access(ulong want_access)
 {
   /* Remove SHOW_VIEW_ACL, because it will be checked during making view */
   want_access&= ~SHOW_VIEW_ACL;
@@ -2461,7 +2489,7 @@ void st_table_list::register_want_access(ulong want_access)
   Load security context information for this view
 
   SYNOPSIS
-    st_table_list::prepare_view_securety_context()
+    TABLE_LIST::prepare_view_securety_context()
     thd                  [in] thread handler
 
   RETURN
@@ -2470,9 +2498,9 @@ void st_table_list::register_want_access(ulong want_access)
 */
 
 #ifndef NO_EMBEDDED_ACCESS_CHECKS
-bool st_table_list::prepare_view_securety_context(THD *thd)
+bool TABLE_LIST::prepare_view_securety_context(THD *thd)
 {
-  DBUG_ENTER("st_table_list::prepare_view_securety_context");
+  DBUG_ENTER("TABLE_LIST::prepare_view_securety_context");
   DBUG_PRINT("enter", ("table: %s", alias));
 
   DBUG_ASSERT(!prelocking_placeholder && view);
@@ -2521,17 +2549,17 @@ bool st_table_list::prepare_view_securety_context(THD *thd)
   Find security context of current view
 
   SYNOPSIS
-    st_table_list::find_view_security_context()
+    TABLE_LIST::find_view_security_context()
     thd                  [in] thread handler
 
 */
 
 #ifndef NO_EMBEDDED_ACCESS_CHECKS
-Security_context *st_table_list::find_view_security_context(THD *thd)
+Security_context *TABLE_LIST::find_view_security_context(THD *thd)
 {
   Security_context *sctx;
   TABLE_LIST *upper_view= this;
-  DBUG_ENTER("st_table_list::find_view_security_context");
+  DBUG_ENTER("TABLE_LIST::find_view_security_context");
 
   DBUG_ASSERT(view);
   while (upper_view && !upper_view->view_suid)
@@ -2560,7 +2588,7 @@ Security_context *st_table_list::find_view_security_context(THD *thd)
   Prepare security context and load underlying tables priveleges for view
 
   SYNOPSIS
-    st_table_list::prepare_security()
+    TABLE_LIST::prepare_security()
     thd                  [in] thread handler
 
   RETURN
@@ -2568,11 +2596,11 @@ Security_context *st_table_list::find_view_security_context(THD *thd)
     TRUE   Error
 */
 
-bool st_table_list::prepare_security(THD *thd)
+bool TABLE_LIST::prepare_security(THD *thd)
 {
   List_iterator_fast<TABLE_LIST> tb(*view_tables);
   TABLE_LIST *tbl;
-  DBUG_ENTER("st_table_list::prepare_security");
+  DBUG_ENTER("TABLE_LIST::prepare_security");
 #ifndef NO_EMBEDDED_ACCESS_CHECKS
   Security_context *save_security_ctx= thd->security_ctx;
 
@@ -3067,10 +3095,10 @@ Field_iterator_table_ref::get_natural_column_ref()
   Cleanup this table for re-execution.
 
   SYNOPSIS
-    st_table_list::reinit_before_use()
+    TABLE_LIST::reinit_before_use()
 */
 
-void st_table_list::reinit_before_use(THD *thd)
+void TABLE_LIST::reinit_before_use(THD *thd)
 {
   /*
     Reset old pointers to TABLEs: they are not valid since the tables
@@ -3097,7 +3125,7 @@ void st_table_list::reinit_before_use(THD *thd)
   Return subselect that contains the FROM list this table is taken from
 
   SYNOPSIS
-    st_table_list::containing_subselect()
+    TABLE_LIST::containing_subselect()
  
   RETURN
     Subselect item for the subquery that contains the FROM list
@@ -3106,7 +3134,7 @@ void st_table_list::reinit_before_use(THD *thd)
 
 */
 
-Item_subselect *st_table_list::containing_subselect()
+Item_subselect *TABLE_LIST::containing_subselect()
 {    
   return (select_lex ? select_lex->master_unit()->item : 0);
 }
